# puppeteer-extra-plugin-block-resources

> A plugin for [puppeteer-extra](https://github.com/berstend/puppeteer-extra).

### Install

```bash
yarn add puppeteer-extra-plugin-block-resources
```

## API

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

#### Table of Contents

-   [Plugin](#plugin)
    -   [availableTypes](#availabletypes)
    -   [blockedTypes](#blockedtypes)

### [Plugin](https://github.com/berstend/puppeteer-extra/blob/db57ea66cf10d407cf63af387892492e495a84f2/packages/puppeteer-extra-plugin-block-resources/index.js#L41-L104)

**Extends: PuppeteerExtraPlugin**

Block resources (images, media, css, etc.) in puppeteer.

Supports all resource types, blocking can be toggled dynamically.

Type: `function (opts)`

-   `opts` **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** Options (optional, default `{}`)
    -   `opts.blockedTypes` **[Set](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Set)&lt;[string](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)>?** Specify which resourceTypes to block (by default none)

Example:

```javascript
const { DEFAULT_INTERCEPT_RESOLUTION_PRIORITY } = require('puppeteer')
puppeteer.use(require('puppeteer-extra-plugin-block-resources')({
  blockedTypes: new Set(['image', 'stylesheet']),
  // Optionally enable Cooperative Mode for several request interceptors
  interceptResolutionPriority: DEFAULT_INTERCEPT_RESOLUTION_PRIORITY
}))

//
// and/or dynamically:
//

const blockResourcesPlugin = require('puppeteer-extra-plugin-block-resources')()
puppeteer.use(blockResourcesPlugin)

const browser = await puppeteer.launch({ headless: false })
const page = await browser.newPage()

blockResourcesPlugin.blockedTypes.add('image')
await page.goto('http://www.msn.com/', {waitUntil: 'domcontentloaded'})

blockResourcesPlugin.blockedTypes.add('stylesheet')
blockResourcesPlugin.blockedTypes.add('other') // e.g. favicon
await page.goto('http://news.ycombinator.com', {waitUntil: 'domcontentloaded'})

blockResourcesPlugin.blockedTypes.delete('stylesheet')
blockResourcesPlugin.blockedTypes.delete('other')
blockResourcesPlugin.blockedTypes.add('media')
blockResourcesPlugin.blockedTypes.add('script')
await page.goto('http://www.youtube.com', {waitUntil: 'domcontentloaded'})
```

* * *

#### [availableTypes](https://github.com/berstend/puppeteer-extra/blob/db57ea66cf10d407cf63af387892492e495a84f2/packages/puppeteer-extra-plugin-block-resources/index.js#L75-L75)

Get all available resource types.

Resource type will be one of the following: `document`, `stylesheet`, `image`, `media`, `font`, `script`, `texttrack`, `xhr`, `fetch`, `eventsource`, `websocket`, `manifest`, `other`.

Type: [Set](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Set)&lt;[string](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)>

* * *

#### [blockedTypes](https://github.com/berstend/puppeteer-extra/blob/db57ea66cf10d407cf63af387892492e495a84f2/packages/puppeteer-extra-plugin-block-resources/index.js#L84-L84)

Get all blocked resource types.

Blocked resource types can be configured either through `opts` or by modifying this property.

Type: [Set](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Set)&lt;[string](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)>

* * *
